@@ -1,8 +1,5 @@
 use crate::ffi;
 
-#[cfg(feature = "alloc")]
-use alloc::vec::Vec;
-
 /// Save the given block of data, overwriting the existing data.
 pub fn save(data: &[u8], private: bool) {
     unsafe {
@@ -34,7 +31,7 @@ pub fn shared_load(cartridge_id: u128, data: &mut [u8]) -> usize {
     }
 }
 
-#[cfg(feature = "alloc")]
+#[cfg(feature = "std")]
 pub fn load_vec() -> Vec<u8> {
     let mut output = Vec::new();
     let size = size();
@@ -45,7 +42,7 @@ pub fn load_vec() -> Vec<u8> {
     output
 }
 
-#[cfg(feature = "alloc")]
+#[cfg(feature = "std")]
 pub fn shared_load_vec(cartridge_id: u128) -> Vec<u8> {
     let mut output = Vec::new();
     let size = shared_size(cartridge_id);
