@@ -33,7 +33,7 @@ impl PressedButtons {
         self.0 &= !button_bit(player, button);
     }
 
-    fn pressed(&mut self, player: u8, button: GamepadButton) -> bool {
+    fn pressed(&self, player: u8, button: GamepadButton) -> bool {
         (self.0 & button_bit(player, button)) != 0
     }
 }
@@ -66,28 +66,28 @@ impl ButtonTracker {
 
     /** Get the state of the previous and current frame, in that order.
      */
-    pub fn state(&mut self, player: u8, button: GamepadButton) -> (bool, bool) {
+    pub fn state(&self, player: u8, button: GamepadButton) -> (bool, bool) {
         (
             self.previous_frame.pressed(player, button),
             self.current_frame.pressed(player, button),
         )
     }
 
-    pub fn pressed(&mut self, player: u8, button: GamepadButton) -> bool {
+    pub fn pressed(&self, player: u8, button: GamepadButton) -> bool {
         self.current_frame.pressed(player, button)
     }
 
-    pub fn just_pressed(&mut self, player: u8, button: GamepadButton) -> bool {
+    pub fn just_pressed(&self, player: u8, button: GamepadButton) -> bool {
         let (previous, current) = self.state(player, button);
         !previous && current
     }
 
-    pub fn just_released(&mut self, player: u8, button: GamepadButton) -> bool {
+    pub fn just_released(&self, player: u8, button: GamepadButton) -> bool {
         let (previous, current) = self.state(player, button);
         previous && !current
     }
 
-    pub fn held(&mut self, player: u8, button: GamepadButton) -> bool {
+    pub fn held(&self, player: u8, button: GamepadButton) -> bool {
         let (previous, current) = self.state(player, button);
         previous && current
     }
