@@ -1,3 +1,5 @@
+use crate::GridUnit;
+
 #[derive(Clone, Copy, Hash, Debug, Eq, PartialEq, Ord, PartialOrd)]
 #[repr(u8)]
 pub enum GamepadButton {
@@ -119,58 +121,60 @@ extern "C" {
     pub fn qwac_canvas_create() -> u32;
     pub fn qwac_canvas_resize(canvas: u32, width_px: u32, height_px: u32);
     pub fn qwac_canvas_clear(canvas: u32);
-    pub fn qwac_canvas_set_global_alpha(canvas: u32, alpha: f64);
+    pub fn qwac_canvas_set_global_alpha(canvas: u32, alpha: f32);
     pub fn qwac_canvas_set_global_composite_operation(canvas: u32, operation: CompositeOperation);
     pub fn qwac_canvas_draw_rectangle(
         canvas: u32,
-        x: f64,
-        y: f64,
-        width: f64,
-        height: f64,
+        x: GridUnit,
+        y: GridUnit,
+        width: GridUnit,
+        height: GridUnit,
         r: u8,
         g: u8,
         b: u8,
         a: u8,
     );
+
     pub fn qwac_canvas_draw_texture(
         canvas: u32,
         texture: u32,
-        source_x: f64,
-        source_y: f64,
-        source_width: f64,
-        source_height: f64,
-        dest_x: f64,
-        dest_y: f64,
-        dest_width: f64,
-        dest_height: f64,
+        source_x: GridUnit,
+        source_y: GridUnit,
+        source_width: GridUnit,
+        source_height: GridUnit,
+        dest_x: GridUnit,
+        dest_y: GridUnit,
+        dest_width: GridUnit,
+        dest_height: GridUnit,
     );
+
     pub fn qwac_canvas_draw_canvas(
         canvas: u32,
         source_canvas: u32,
-        source_x: f64,
-        source_y: f64,
-        source_width: f64,
-        source_height: f64,
-        dest_x: f64,
-        dest_y: f64,
-        dest_width: f64,
-        dest_height: f64,
+        source_x: GridUnit,
+        source_y: GridUnit,
+        source_width: GridUnit,
+        source_height: GridUnit,
+        dest_x: GridUnit,
+        dest_y: GridUnit,
+        dest_width: GridUnit,
+        dest_height: GridUnit,
     );
 
     pub fn qwac_canvas_delete(canvas: u32);
 
     pub fn qwac_audio_buffer_from_opus(data: *const u8, size: u32) -> u32;
     pub fn qwac_audio_oscillator(oscillator_type: OscillatorType) -> u32;
-    pub fn qwac_audio_source_delay(audio_node: u32, seconds: f64);
-    pub fn qwac_audio_source_length(audio_node: u32, seconds: f64);
+    pub fn qwac_audio_source_delay(audio_node: u32, seconds: f32);
+    pub fn qwac_audio_source_length(audio_node: u32, seconds: f32);
     pub fn qwac_audio_source_play(audio_node: u32);
     pub fn qwac_audio_source_stop(audio_node: u32);
     pub fn qwac_audio_gain() -> u32;
-    pub fn qwac_audio_delay(max_seconds: f64) -> u32;
-    pub fn qwac_audio_set_value(audio_node: u32, value: f64);
-    pub fn qwac_audio_set_value_at_time(audio_node: u32, time: f64, value: f64);
-    pub fn qwac_audio_linear_ramp_to_value_at_time(audio_node: u32, time: f64, value: f64);
-    pub fn qwac_audio_exponential_ramp_to_value_at_time(audio_node: u32, time: f64, value: f64);
+    pub fn qwac_audio_delay(max_seconds: f32) -> u32;
+    pub fn qwac_audio_set_value(audio_node: u32, value: f32);
+    pub fn qwac_audio_set_value_at_time(audio_node: u32, time: f32, value: f32);
+    pub fn qwac_audio_linear_ramp_to_value_at_time(audio_node: u32, time: f32, value: f32);
+    pub fn qwac_audio_exponential_ramp_to_value_at_time(audio_node: u32, time: f32, value: f32);
     pub fn qwac_audio_connect(source: u32, target: u32);
     pub fn qwac_audio_disconnect(source: u32, target: u32);
     pub fn qwac_audio_sink(audio_node: u32);
@@ -186,7 +190,7 @@ extern "C" {
     pub fn qwac_data_save(data: *const u8, size: u32, private: u8);
     pub fn qwac_data_load(data: *mut u8, size: u32) -> u32;
 
-    // game_id is the first 16 bytes of the SHA512 sum.
+    // game_id is the first 16 bytes of the SHA512 sum, in big-endian order.
     pub fn qwac_data_shared_load(game_id: *const u8, data: *mut u8, size: u32) -> u32;
     pub fn qwac_data_size() -> u32;
     pub fn qwac_data_shared_size(game_id: *const u8) -> u32;
